# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/compression/gzip/compressor/v3/gzip.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/compression/gzip/compressor/v3/gzip.proto',
  package='envoy.extensions.compression.gzip.compressor.v3',
  syntax='proto3',
  serialized_options=b'\n=io.envoyproxy.envoy.extensions.compression.gzip.compressor.v3B\tGzipProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n:envoy/extensions/compression/gzip/compressor/v3/gzip.proto\x12/envoy.extensions.compression.gzip.compressor.v3\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xbd\x06\n\x04Gzip\x12=\n\x0cmemory_level\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\t(\x01\x12k\n\x11\x63ompression_level\x18\x02 \x01(\x0e\x32\x46.envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionLevelB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12q\n\x14\x63ompression_strategy\x18\x03 \x01(\x0e\x32I.envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionStrategyB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12<\n\x0bwindow_bits\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\t\xfa\x42\x06*\x04\x18\x0f(\t\x12>\n\nchunk_size\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x0c\xfa\x42\t*\x07\x18\x80\x80\x04(\x80 \"_\n\x13\x43ompressionStrategy\x12\x14\n\x10\x44\x45\x46\x41ULT_STRATEGY\x10\x00\x12\x0c\n\x08\x46ILTERED\x10\x01\x12\x10\n\x0cHUFFMAN_ONLY\x10\x02\x12\x07\n\x03RLE\x10\x03\x12\t\n\x05\x46IXED\x10\x04\"\xb6\x02\n\x10\x43ompressionLevel\x12\x17\n\x13\x44\x45\x46\x41ULT_COMPRESSION\x10\x00\x12\x0e\n\nBEST_SPEED\x10\x01\x12\x17\n\x13\x43OMPRESSION_LEVEL_1\x10\x01\x12\x17\n\x13\x43OMPRESSION_LEVEL_2\x10\x02\x12\x17\n\x13\x43OMPRESSION_LEVEL_3\x10\x03\x12\x17\n\x13\x43OMPRESSION_LEVEL_4\x10\x04\x12\x17\n\x13\x43OMPRESSION_LEVEL_5\x10\x05\x12\x17\n\x13\x43OMPRESSION_LEVEL_6\x10\x06\x12\x17\n\x13\x43OMPRESSION_LEVEL_7\x10\x07\x12\x17\n\x13\x43OMPRESSION_LEVEL_8\x10\x08\x12\x17\n\x13\x43OMPRESSION_LEVEL_9\x10\t\x12\x14\n\x10\x42\x45ST_COMPRESSION\x10\t\x1a\x02\x10\x01\x42T\n=io.envoyproxy.envoy.extensions.compression.gzip.compressor.v3B\tGzipProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_GZIP_COMPRESSIONSTRATEGY = _descriptor.EnumDescriptor(
  name='CompressionStrategy',
  full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionStrategy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_STRATEGY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FILTERED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HUFFMAN_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RLE', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='FIXED', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=621,
  serialized_end=716,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONSTRATEGY)

_GZIP_COMPRESSIONLEVEL = _descriptor.EnumDescriptor(
  name='CompressionLevel',
  full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip.CompressionLevel',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DEFAULT_COMPRESSION', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST_SPEED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_1', index=2, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_2', index=3, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_3', index=4, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_4', index=5, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_5', index=6, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_6', index=7, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_7', index=8, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_8', index=9, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMPRESSION_LEVEL_9', index=10, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BEST_COMPRESSION', index=11, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=b'\020\001',
  serialized_start=719,
  serialized_end=1029,
)
_sym_db.RegisterEnumDescriptor(_GZIP_COMPRESSIONLEVEL)


_GZIP = _descriptor.Descriptor(
  name='Gzip',
  full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='memory_level', full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip.memory_level', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\t(\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_level', full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip.compression_level', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='compression_strategy', full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip.compression_strategy', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window_bits', full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip.window_bits', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006*\004\030\017(\t', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chunk_size', full_name='envoy.extensions.compression.gzip.compressor.v3.Gzip.chunk_size', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t*\007\030\200\200\004(\200 ', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _GZIP_COMPRESSIONSTRATEGY,
    _GZIP_COMPRESSIONLEVEL,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=200,
  serialized_end=1029,
)

_GZIP.fields_by_name['memory_level'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['compression_level'].enum_type = _GZIP_COMPRESSIONLEVEL
_GZIP.fields_by_name['compression_strategy'].enum_type = _GZIP_COMPRESSIONSTRATEGY
_GZIP.fields_by_name['window_bits'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP.fields_by_name['chunk_size'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_GZIP_COMPRESSIONSTRATEGY.containing_type = _GZIP
_GZIP_COMPRESSIONLEVEL.containing_type = _GZIP
DESCRIPTOR.message_types_by_name['Gzip'] = _GZIP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Gzip = _reflection.GeneratedProtocolMessageType('Gzip', (_message.Message,), {
  'DESCRIPTOR' : _GZIP,
  '__module__' : 'envoy.extensions.compression.gzip.compressor.v3.gzip_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.compression.gzip.compressor.v3.Gzip)
  })
_sym_db.RegisterMessage(Gzip)


DESCRIPTOR._options = None
_GZIP_COMPRESSIONLEVEL._options = None
_GZIP.fields_by_name['memory_level']._options = None
_GZIP.fields_by_name['compression_level']._options = None
_GZIP.fields_by_name['compression_strategy']._options = None
_GZIP.fields_by_name['window_bits']._options = None
_GZIP.fields_by_name['chunk_size']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto',
  package='envoy.extensions.internal_redirect.allow_listed_routes.v3',
  syntax='proto3',
  serialized_options=b'\nGio.envoyproxy.envoy.extensions.internal_redirect.allow_listed_routes.v3B\034AllowListedRoutesConfigProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nZenvoy/extensions/internal_redirect/allow_listed_routes/v3/allow_listed_routes_config.proto\x12\x39\x65nvoy.extensions.internal_redirect.allow_listed_routes.v3\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"D\n\x17\x41llowListedRoutesConfig\x12)\n\x13\x61llowed_route_names\x18\x01 \x03(\tB\x0c\xfa\x42\t\x92\x01\x06\"\x04r\x02\x10\x01\x42q\nGio.envoyproxy.envoy.extensions.internal_redirect.allow_listed_routes.v3B\x1c\x41llowListedRoutesConfigProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ALLOWLISTEDROUTESCONFIG = _descriptor.Descriptor(
  name='AllowListedRoutesConfig',
  full_name='envoy.extensions.internal_redirect.allow_listed_routes.v3.AllowListedRoutesConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allowed_route_names', full_name='envoy.extensions.internal_redirect.allow_listed_routes.v3.AllowListedRoutesConfig.allowed_route_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\t\222\001\006\"\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=209,
  serialized_end=277,
)

DESCRIPTOR.message_types_by_name['AllowListedRoutesConfig'] = _ALLOWLISTEDROUTESCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AllowListedRoutesConfig = _reflection.GeneratedProtocolMessageType('AllowListedRoutesConfig', (_message.Message,), {
  'DESCRIPTOR' : _ALLOWLISTEDROUTESCONFIG,
  '__module__' : 'envoy.extensions.internal_redirect.allow_listed_routes.v3.allow_listed_routes_config_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.internal_redirect.allow_listed_routes.v3.AllowListedRoutesConfig)
  })
_sym_db.RegisterMessage(AllowListedRoutesConfig)


DESCRIPTOR._options = None
_ALLOWLISTEDROUTESCONFIG.fields_by_name['allowed_route_names']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/type/v3/range.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/type/v3/range.proto',
  package='envoy.type.v3',
  syntax='proto3',
  serialized_options=b'\n\033io.envoyproxy.envoy.type.v3B\nRangeProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x19\x65nvoy/type/v3/range.proto\x12\renvoy.type.v3\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"F\n\nInt64Range\x12\r\n\x05start\x18\x01 \x01(\x03\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x03:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.type.Int64Range\"F\n\nInt32Range\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x05:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.type.Int32Range\"H\n\x0b\x44oubleRange\x12\r\n\x05start\x18\x01 \x01(\x01\x12\x0b\n\x03\x65nd\x18\x02 \x01(\x01:\x1d\x9a\xc5\x88\x1e\x18\n\x16\x65nvoy.type.DoubleRangeB3\n\x1bio.envoyproxy.envoy.type.v3B\nRangeProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_INT64RANGE = _descriptor.Descriptor(
  name='Int64Range',
  full_name='envoy.type.v3.Int64Range',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='envoy.type.v3.Int64Range.start', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='envoy.type.v3.Int64Range.end', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.type.Int64Range',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=110,
  serialized_end=180,
)


_INT32RANGE = _descriptor.Descriptor(
  name='Int32Range',
  full_name='envoy.type.v3.Int32Range',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='envoy.type.v3.Int32Range.start', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='envoy.type.v3.Int32Range.end', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.type.Int32Range',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=182,
  serialized_end=252,
)


_DOUBLERANGE = _descriptor.Descriptor(
  name='DoubleRange',
  full_name='envoy.type.v3.DoubleRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='envoy.type.v3.DoubleRange.start', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end', full_name='envoy.type.v3.DoubleRange.end', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\030\n\026envoy.type.DoubleRange',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=254,
  serialized_end=326,
)

DESCRIPTOR.message_types_by_name['Int64Range'] = _INT64RANGE
DESCRIPTOR.message_types_by_name['Int32Range'] = _INT32RANGE
DESCRIPTOR.message_types_by_name['DoubleRange'] = _DOUBLERANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Int64Range = _reflection.GeneratedProtocolMessageType('Int64Range', (_message.Message,), {
  'DESCRIPTOR' : _INT64RANGE,
  '__module__' : 'envoy.type.v3.range_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.v3.Int64Range)
  })
_sym_db.RegisterMessage(Int64Range)

Int32Range = _reflection.GeneratedProtocolMessageType('Int32Range', (_message.Message,), {
  'DESCRIPTOR' : _INT32RANGE,
  '__module__' : 'envoy.type.v3.range_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.v3.Int32Range)
  })
_sym_db.RegisterMessage(Int32Range)

DoubleRange = _reflection.GeneratedProtocolMessageType('DoubleRange', (_message.Message,), {
  'DESCRIPTOR' : _DOUBLERANGE,
  '__module__' : 'envoy.type.v3.range_pb2'
  # @@protoc_insertion_point(class_scope:envoy.type.v3.DoubleRange)
  })
_sym_db.RegisterMessage(DoubleRange)


DESCRIPTOR._options = None
_INT64RANGE._options = None
_INT32RANGE._options = None
_DOUBLERANGE._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/core/v3/health_check.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import event_service_config_pb2 as envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2
from envoy.type.matcher.v3 import string_pb2 as envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2
from envoy.type.v3 import http_pb2 as envoy_dot_type_dot_v3_dot_http__pb2
from envoy.type.v3 import range_pb2 as envoy_dot_type_dot_v3_dot_range__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/core/v3/health_check.proto',
  package='envoy.config.core.v3',
  syntax='proto3',
  serialized_options=b'\n\"io.envoyproxy.envoy.config.core.v3B\020HealthCheckProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/config/core/v3/health_check.proto\x12\x14\x65nvoy.config.core.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a/envoy/config/core/v3/event_service_config.proto\x1a\"envoy/type/matcher/v3/string.proto\x1a\x18\x65nvoy/type/v3/http.proto\x1a\x19\x65nvoy/type/v3/range.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\xcb\x16\n\x0bHealthCheck\x12\x36\n\x07timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x37\n\x08interval\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\x42\x07\xaa\x01\x04\x08\x01*\x00\x12\x31\n\x0einitial_jitter\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0finterval_jitter\x18\x03 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x1f\n\x17interval_jitter_percent\x18\x12 \x01(\r\x12\x43\n\x13unhealthy_threshold\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12\x41\n\x11healthy_threshold\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x12.\n\x08\x61lt_port\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x34\n\x10reuse_connection\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12N\n\x11http_health_check\x18\x08 \x01(\x0b\x32\x31.envoy.config.core.v3.HealthCheck.HttpHealthCheckH\x00\x12L\n\x10tcp_health_check\x18\t \x01(\x0b\x32\x30.envoy.config.core.v3.HealthCheck.TcpHealthCheckH\x00\x12N\n\x11grpc_health_check\x18\x0b \x01(\x0b\x32\x31.envoy.config.core.v3.HealthCheck.GrpcHealthCheckH\x00\x12R\n\x13\x63ustom_health_check\x18\r \x01(\x0b\x32\x33.envoy.config.core.v3.HealthCheck.CustomHealthCheckH\x00\x12@\n\x13no_traffic_interval\x18\x0c \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12H\n\x1bno_traffic_healthy_interval\x18\x18 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12?\n\x12unhealthy_interval\x18\x0e \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x44\n\x17unhealthy_edge_interval\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x42\n\x15healthy_edge_interval\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x12\x16\n\x0e\x65vent_log_path\x18\x11 \x01(\t\x12?\n\revent_service\x18\x16 \x01(\x0b\x32(.envoy.config.core.v3.EventServiceConfig\x12(\n always_log_health_check_failures\x18\x13 \x01(\x08\x12\x41\n\x0btls_options\x18\x15 \x01(\x0b\x32,.envoy.config.core.v3.HealthCheck.TlsOptions\x12@\n\x1ftransport_socket_match_criteria\x18\x17 \x01(\x0b\x32\x17.google.protobuf.Struct\x1ar\n\x07Payload\x12\x17\n\x04text\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00\x12\x10\n\x06\x62inary\x18\x02 \x01(\x0cH\x00:,\x9a\xc5\x88\x1e\'\n%envoy.api.v2.core.HealthCheck.PayloadB\x0e\n\x07payload\x12\x03\xf8\x42\x01\x1a\xe1\x04\n\x0fHttpHealthCheck\x12\x19\n\x04host\x18\x01 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x12\x1b\n\x04path\x18\x02 \x01(\tB\r\xfa\x42\nr\x08\x10\x01\xc0\x01\x02\xc8\x01\x00\x12\x37\n\x04send\x18\x03 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12:\n\x07receive\x18\x04 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12R\n\x16request_headers_to_add\x18\x06 \x03(\x0b\x32\'.envoy.config.core.v3.HeaderValueOptionB\t\xfa\x42\x06\x92\x01\x03\x10\xe8\x07\x12\x33\n\x19request_headers_to_remove\x18\x08 \x03(\tB\x10\xfa\x42\r\x92\x01\n\"\x08r\x06\xc0\x01\x01\xc8\x01\x00\x12\x34\n\x11\x65xpected_statuses\x18\t \x03(\x0b\x32\x19.envoy.type.v3.Int64Range\x12\x43\n\x11\x63odec_client_type\x18\n \x01(\x0e\x32\x1e.envoy.type.v3.CodecClientTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12\x42\n\x14service_name_matcher\x18\x0b \x01(\x0b\x32$.envoy.type.matcher.v3.StringMatcher:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.HealthCheck.HttpHealthCheckJ\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08R\x0cservice_nameR\tuse_http2\x1a\xba\x01\n\x0eTcpHealthCheck\x12\x37\n\x04send\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload\x12:\n\x07receive\x18\x02 \x03(\x0b\x32).envoy.config.core.v3.HealthCheck.Payload:3\x9a\xc5\x88\x1e.\n,envoy.api.v2.core.HealthCheck.TcpHealthCheck\x1aV\n\x10RedisHealthCheck\x12\x0b\n\x03key\x18\x01 \x01(\t:5\x9a\xc5\x88\x1e\x30\n.envoy.api.v2.core.HealthCheck.RedisHealthCheck\x1a}\n\x0fGrpcHealthCheck\x12\x14\n\x0cservice_name\x18\x01 \x01(\t\x12\x1e\n\tauthority\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00:4\x9a\xc5\x88\x1e/\n-envoy.api.v2.core.HealthCheck.GrpcHealthCheck\x1a\xad\x01\n\x11\x43ustomHealthCheck\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12,\n\x0ctyped_config\x18\x03 \x01(\x0b\x32\x14.google.protobuf.AnyH\x00:6\x9a\xc5\x88\x1e\x31\n/envoy.api.v2.core.HealthCheck.CustomHealthCheckB\r\n\x0b\x63onfig_typeJ\x04\x08\x02\x10\x03R\x06\x63onfig\x1aU\n\nTlsOptions\x12\x16\n\x0e\x61lpn_protocols\x18\x01 \x03(\t:/\x9a\xc5\x88\x1e*\n(envoy.api.v2.core.HealthCheck.TlsOptions:$\x9a\xc5\x88\x1e\x1f\n\x1d\x65nvoy.api.v2.core.HealthCheckB\x15\n\x0ehealth_checker\x12\x03\xf8\x42\x01J\x04\x08\n\x10\x0b*`\n\x0cHealthStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07HEALTHY\x10\x01\x12\r\n\tUNHEALTHY\x10\x02\x12\x0c\n\x08\x44RAINING\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x44\x45GRADED\x10\x05\x42@\n\"io.envoyproxy.envoy.config.core.v3B\x10HealthCheckProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2.DESCRIPTOR,envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_http__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_range__pb2.DESCRIPTOR,google_dot_protobuf_dot_any__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])

_HEALTHSTATUS = _descriptor.EnumDescriptor(
  name='HealthStatus',
  full_name='envoy.config.core.v3.HealthStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HEALTHY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNHEALTHY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DRAINING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TIMEOUT', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEGRADED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3342,
  serialized_end=3438,
)
_sym_db.RegisterEnumDescriptor(_HEALTHSTATUS)

HealthStatus = enum_type_wrapper.EnumTypeWrapper(_HEALTHSTATUS)
UNKNOWN = 0
HEALTHY = 1
UNHEALTHY = 2
DRAINING = 3
TIMEOUT = 4
DEGRADED = 5



_HEALTHCHECK_PAYLOAD = _descriptor.Descriptor(
  name='Payload',
  full_name='envoy.config.core.v3.HealthCheck.Payload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='text', full_name='envoy.config.core.v3.HealthCheck.Payload.text', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='binary', full_name='envoy.config.core.v3.HealthCheck.Payload.binary', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\'\n%envoy.api.v2.core.HealthCheck.Payload',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='payload', full_name='envoy.config.core.v3.HealthCheck.Payload.payload',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=1880,
  serialized_end=1994,
)

_HEALTHCHECK_HTTPHEALTHCHECK = _descriptor.Descriptor(
  name='HttpHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='host', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.host', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\nr\010\020\001\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='send', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.send', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.receive', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_add', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.request_headers_to_add', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\222\001\003\020\350\007', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_headers_to_remove', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.request_headers_to_remove', index=5,
      number=8, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\r\222\001\n\"\010r\006\300\001\001\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expected_statuses', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.expected_statuses', index=6,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='codec_client_type', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.codec_client_type', index=7,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='service_name_matcher', full_name='envoy.config.core.v3.HealthCheck.HttpHealthCheck.service_name_matcher', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.api.v2.core.HealthCheck.HttpHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1997,
  serialized_end=2606,
)

_HEALTHCHECK_TCPHEALTHCHECK = _descriptor.Descriptor(
  name='TcpHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.TcpHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='send', full_name='envoy.config.core.v3.HealthCheck.TcpHealthCheck.send', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='receive', full_name='envoy.config.core.v3.HealthCheck.TcpHealthCheck.receive', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036.\n,envoy.api.v2.core.HealthCheck.TcpHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2609,
  serialized_end=2795,
)

_HEALTHCHECK_REDISHEALTHCHECK = _descriptor.Descriptor(
  name='RedisHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.RedisHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.core.v3.HealthCheck.RedisHealthCheck.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0360\n.envoy.api.v2.core.HealthCheck.RedisHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2797,
  serialized_end=2883,
)

_HEALTHCHECK_GRPCHEALTHCHECK = _descriptor.Descriptor(
  name='GrpcHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.GrpcHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='service_name', full_name='envoy.config.core.v3.HealthCheck.GrpcHealthCheck.service_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='authority', full_name='envoy.config.core.v3.HealthCheck.GrpcHealthCheck.authority', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036/\n-envoy.api.v2.core.HealthCheck.GrpcHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=3010,
)

_HEALTHCHECK_CUSTOMHEALTHCHECK = _descriptor.Descriptor(
  name='CustomHealthCheck',
  full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='typed_config', full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck.typed_config', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0361\n/envoy.api.v2.core.HealthCheck.CustomHealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='config_type', full_name='envoy.config.core.v3.HealthCheck.CustomHealthCheck.config_type',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=3013,
  serialized_end=3186,
)

_HEALTHCHECK_TLSOPTIONS = _descriptor.Descriptor(
  name='TlsOptions',
  full_name='envoy.config.core.v3.HealthCheck.TlsOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='alpn_protocols', full_name='envoy.config.core.v3.HealthCheck.TlsOptions.alpn_protocols', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036*\n(envoy.api.v2.core.HealthCheck.TlsOptions',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3188,
  serialized_end=3273,
)

_HEALTHCHECK = _descriptor.Descriptor(
  name='HealthCheck',
  full_name='envoy.config.core.v3.HealthCheck',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timeout', full_name='envoy.config.core.v3.HealthCheck.timeout', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval', full_name='envoy.config.core.v3.HealthCheck.interval', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\252\001\004\010\001*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='initial_jitter', full_name='envoy.config.core.v3.HealthCheck.initial_jitter', index=2,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval_jitter', full_name='envoy.config.core.v3.HealthCheck.interval_jitter', index=3,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='interval_jitter_percent', full_name='envoy.config.core.v3.HealthCheck.interval_jitter_percent', index=4,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_threshold', full_name='envoy.config.core.v3.HealthCheck.unhealthy_threshold', index=5,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthy_threshold', full_name='envoy.config.core.v3.HealthCheck.healthy_threshold', index=6,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='alt_port', full_name='envoy.config.core.v3.HealthCheck.alt_port', index=7,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reuse_connection', full_name='envoy.config.core.v3.HealthCheck.reuse_connection', index=8,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http_health_check', full_name='envoy.config.core.v3.HealthCheck.http_health_check', index=9,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tcp_health_check', full_name='envoy.config.core.v3.HealthCheck.tcp_health_check', index=10,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc_health_check', full_name='envoy.config.core.v3.HealthCheck.grpc_health_check', index=11,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='custom_health_check', full_name='envoy.config.core.v3.HealthCheck.custom_health_check', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_traffic_interval', full_name='envoy.config.core.v3.HealthCheck.no_traffic_interval', index=13,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='no_traffic_healthy_interval', full_name='envoy.config.core.v3.HealthCheck.no_traffic_healthy_interval', index=14,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_interval', full_name='envoy.config.core.v3.HealthCheck.unhealthy_interval', index=15,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unhealthy_edge_interval', full_name='envoy.config.core.v3.HealthCheck.unhealthy_edge_interval', index=16,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='healthy_edge_interval', full_name='envoy.config.core.v3.HealthCheck.healthy_edge_interval', index=17,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_log_path', full_name='envoy.config.core.v3.HealthCheck.event_log_path', index=18,
      number=17, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='event_service', full_name='envoy.config.core.v3.HealthCheck.event_service', index=19,
      number=22, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='always_log_health_check_failures', full_name='envoy.config.core.v3.HealthCheck.always_log_health_check_failures', index=20,
      number=19, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tls_options', full_name='envoy.config.core.v3.HealthCheck.tls_options', index=21,
      number=21, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket_match_criteria', full_name='envoy.config.core.v3.HealthCheck.transport_socket_match_criteria', index=22,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_HEALTHCHECK_PAYLOAD, _HEALTHCHECK_HTTPHEALTHCHECK, _HEALTHCHECK_TCPHEALTHCHECK, _HEALTHCHECK_REDISHEALTHCHECK, _HEALTHCHECK_GRPCHEALTHCHECK, _HEALTHCHECK_CUSTOMHEALTHCHECK, _HEALTHCHECK_TLSOPTIONS, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\037\n\035envoy.api.v2.core.HealthCheck',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='health_checker', full_name='envoy.config.core.v3.HealthCheck.health_checker',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=449,
  serialized_end=3340,
)

_HEALTHCHECK_PAYLOAD.containing_type = _HEALTHCHECK
_HEALTHCHECK_PAYLOAD.oneofs_by_name['payload'].fields.append(
  _HEALTHCHECK_PAYLOAD.fields_by_name['text'])
_HEALTHCHECK_PAYLOAD.fields_by_name['text'].containing_oneof = _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']
_HEALTHCHECK_PAYLOAD.oneofs_by_name['payload'].fields.append(
  _HEALTHCHECK_PAYLOAD.fields_by_name['binary'])
_HEALTHCHECK_PAYLOAD.fields_by_name['binary'].containing_oneof = _HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['send'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['receive'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._HEADERVALUEOPTION
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['expected_statuses'].message_type = envoy_dot_type_dot_v3_dot_range__pb2._INT64RANGE
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type'].enum_type = envoy_dot_type_dot_v3_dot_http__pb2._CODECCLIENTTYPE
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['service_name_matcher'].message_type = envoy_dot_type_dot_matcher_dot_v3_dot_string__pb2._STRINGMATCHER
_HEALTHCHECK_HTTPHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_TCPHEALTHCHECK.fields_by_name['send'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_TCPHEALTHCHECK.fields_by_name['receive'].message_type = _HEALTHCHECK_PAYLOAD
_HEALTHCHECK_TCPHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_REDISHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_GRPCHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['typed_config'].message_type = google_dot_protobuf_dot_any__pb2._ANY
_HEALTHCHECK_CUSTOMHEALTHCHECK.containing_type = _HEALTHCHECK
_HEALTHCHECK_CUSTOMHEALTHCHECK.oneofs_by_name['config_type'].fields.append(
  _HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['typed_config'])
_HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['typed_config'].containing_oneof = _HEALTHCHECK_CUSTOMHEALTHCHECK.oneofs_by_name['config_type']
_HEALTHCHECK_TLSOPTIONS.containing_type = _HEALTHCHECK
_HEALTHCHECK.fields_by_name['timeout'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['initial_jitter'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['interval_jitter'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['unhealthy_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HEALTHCHECK.fields_by_name['healthy_threshold'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HEALTHCHECK.fields_by_name['alt_port'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_HEALTHCHECK.fields_by_name['reuse_connection'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_HEALTHCHECK.fields_by_name['http_health_check'].message_type = _HEALTHCHECK_HTTPHEALTHCHECK
_HEALTHCHECK.fields_by_name['tcp_health_check'].message_type = _HEALTHCHECK_TCPHEALTHCHECK
_HEALTHCHECK.fields_by_name['grpc_health_check'].message_type = _HEALTHCHECK_GRPCHEALTHCHECK
_HEALTHCHECK.fields_by_name['custom_health_check'].message_type = _HEALTHCHECK_CUSTOMHEALTHCHECK
_HEALTHCHECK.fields_by_name['no_traffic_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['no_traffic_healthy_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['unhealthy_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['unhealthy_edge_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['healthy_edge_interval'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_HEALTHCHECK.fields_by_name['event_service'].message_type = envoy_dot_config_dot_core_dot_v3_dot_event__service__config__pb2._EVENTSERVICECONFIG
_HEALTHCHECK.fields_by_name['tls_options'].message_type = _HEALTHCHECK_TLSOPTIONS
_HEALTHCHECK.fields_by_name['transport_socket_match_criteria'].message_type = google_dot_protobuf_dot_struct__pb2._STRUCT
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['http_health_check'])
_HEALTHCHECK.fields_by_name['http_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['tcp_health_check'])
_HEALTHCHECK.fields_by_name['tcp_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['grpc_health_check'])
_HEALTHCHECK.fields_by_name['grpc_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
_HEALTHCHECK.oneofs_by_name['health_checker'].fields.append(
  _HEALTHCHECK.fields_by_name['custom_health_check'])
_HEALTHCHECK.fields_by_name['custom_health_check'].containing_oneof = _HEALTHCHECK.oneofs_by_name['health_checker']
DESCRIPTOR.message_types_by_name['HealthCheck'] = _HEALTHCHECK
DESCRIPTOR.enum_types_by_name['HealthStatus'] = _HEALTHSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

HealthCheck = _reflection.GeneratedProtocolMessageType('HealthCheck', (_message.Message,), {

  'Payload' : _reflection.GeneratedProtocolMessageType('Payload', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_PAYLOAD,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.Payload)
    })
  ,

  'HttpHealthCheck' : _reflection.GeneratedProtocolMessageType('HttpHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_HTTPHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.HttpHealthCheck)
    })
  ,

  'TcpHealthCheck' : _reflection.GeneratedProtocolMessageType('TcpHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_TCPHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.TcpHealthCheck)
    })
  ,

  'RedisHealthCheck' : _reflection.GeneratedProtocolMessageType('RedisHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_REDISHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.RedisHealthCheck)
    })
  ,

  'GrpcHealthCheck' : _reflection.GeneratedProtocolMessageType('GrpcHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_GRPCHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.GrpcHealthCheck)
    })
  ,

  'CustomHealthCheck' : _reflection.GeneratedProtocolMessageType('CustomHealthCheck', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_CUSTOMHEALTHCHECK,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.CustomHealthCheck)
    })
  ,

  'TlsOptions' : _reflection.GeneratedProtocolMessageType('TlsOptions', (_message.Message,), {
    'DESCRIPTOR' : _HEALTHCHECK_TLSOPTIONS,
    '__module__' : 'envoy.config.core.v3.health_check_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck.TlsOptions)
    })
  ,
  'DESCRIPTOR' : _HEALTHCHECK,
  '__module__' : 'envoy.config.core.v3.health_check_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.core.v3.HealthCheck)
  })
_sym_db.RegisterMessage(HealthCheck)
_sym_db.RegisterMessage(HealthCheck.Payload)
_sym_db.RegisterMessage(HealthCheck.HttpHealthCheck)
_sym_db.RegisterMessage(HealthCheck.TcpHealthCheck)
_sym_db.RegisterMessage(HealthCheck.RedisHealthCheck)
_sym_db.RegisterMessage(HealthCheck.GrpcHealthCheck)
_sym_db.RegisterMessage(HealthCheck.CustomHealthCheck)
_sym_db.RegisterMessage(HealthCheck.TlsOptions)


DESCRIPTOR._options = None
_HEALTHCHECK_PAYLOAD.oneofs_by_name['payload']._options = None
_HEALTHCHECK_PAYLOAD.fields_by_name['text']._options = None
_HEALTHCHECK_PAYLOAD._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['host']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['path']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_add']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['request_headers_to_remove']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK.fields_by_name['codec_client_type']._options = None
_HEALTHCHECK_HTTPHEALTHCHECK._options = None
_HEALTHCHECK_TCPHEALTHCHECK._options = None
_HEALTHCHECK_REDISHEALTHCHECK._options = None
_HEALTHCHECK_GRPCHEALTHCHECK.fields_by_name['authority']._options = None
_HEALTHCHECK_GRPCHEALTHCHECK._options = None
_HEALTHCHECK_CUSTOMHEALTHCHECK.fields_by_name['name']._options = None
_HEALTHCHECK_CUSTOMHEALTHCHECK._options = None
_HEALTHCHECK_TLSOPTIONS._options = None
_HEALTHCHECK.oneofs_by_name['health_checker']._options = None
_HEALTHCHECK.fields_by_name['timeout']._options = None
_HEALTHCHECK.fields_by_name['interval']._options = None
_HEALTHCHECK.fields_by_name['unhealthy_threshold']._options = None
_HEALTHCHECK.fields_by_name['healthy_threshold']._options = None
_HEALTHCHECK.fields_by_name['no_traffic_interval']._options = None
_HEALTHCHECK.fields_by_name['no_traffic_healthy_interval']._options = None
_HEALTHCHECK.fields_by_name['unhealthy_interval']._options = None
_HEALTHCHECK.fields_by_name['unhealthy_edge_interval']._options = None
_HEALTHCHECK.fields_by_name['healthy_edge_interval']._options = None
_HEALTHCHECK._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/transport_sockets/proxy_protocol/v3/upstream_proxy_protocol.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v3 import base_pb2 as envoy_dot_config_dot_core_dot_v3_dot_base__pb2
from envoy.config.core.v3 import proxy_protocol_pb2 as envoy_dot_config_dot_core_dot_v3_dot_proxy__protocol__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/transport_sockets/proxy_protocol/v3/upstream_proxy_protocol.proto',
  package='envoy.extensions.transport_sockets.proxy_protocol.v3',
  syntax='proto3',
  serialized_options=b'\nBio.envoyproxy.envoy.extensions.transport_sockets.proxy_protocol.v3B\032UpstreamProxyProtocolProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nRenvoy/extensions/transport_sockets/proxy_protocol/v3/upstream_proxy_protocol.proto\x12\x34\x65nvoy.extensions.transport_sockets.proxy_protocol.v3\x1a\x1f\x65nvoy/config/core/v3/base.proto\x1a)envoy/config/core/v3/proxy_protocol.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xa6\x01\n\x1eProxyProtocolUpstreamTransport\x12\x39\n\x06\x63onfig\x18\x01 \x01(\x0b\x32).envoy.config.core.v3.ProxyProtocolConfig\x12I\n\x10transport_socket\x18\x02 \x01(\x0b\x32%.envoy.config.core.v3.TransportSocketB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01\x42j\nBio.envoyproxy.envoy.extensions.transport_sockets.proxy_protocol.v3B\x1aUpstreamProxyProtocolProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v3_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v3_dot_proxy__protocol__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_PROXYPROTOCOLUPSTREAMTRANSPORT = _descriptor.Descriptor(
  name='ProxyProtocolUpstreamTransport',
  full_name='envoy.extensions.transport_sockets.proxy_protocol.v3.ProxyProtocolUpstreamTransport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='config', full_name='envoy.extensions.transport_sockets.proxy_protocol.v3.ProxyProtocolUpstreamTransport.config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='transport_socket', full_name='envoy.extensions.transport_sockets.proxy_protocol.v3.ProxyProtocolUpstreamTransport.transport_socket', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=273,
  serialized_end=439,
)

_PROXYPROTOCOLUPSTREAMTRANSPORT.fields_by_name['config'].message_type = envoy_dot_config_dot_core_dot_v3_dot_proxy__protocol__pb2._PROXYPROTOCOLCONFIG
_PROXYPROTOCOLUPSTREAMTRANSPORT.fields_by_name['transport_socket'].message_type = envoy_dot_config_dot_core_dot_v3_dot_base__pb2._TRANSPORTSOCKET
DESCRIPTOR.message_types_by_name['ProxyProtocolUpstreamTransport'] = _PROXYPROTOCOLUPSTREAMTRANSPORT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ProxyProtocolUpstreamTransport = _reflection.GeneratedProtocolMessageType('ProxyProtocolUpstreamTransport', (_message.Message,), {
  'DESCRIPTOR' : _PROXYPROTOCOLUPSTREAMTRANSPORT,
  '__module__' : 'envoy.extensions.transport_sockets.proxy_protocol.v3.upstream_proxy_protocol_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.transport_sockets.proxy_protocol.v3.ProxyProtocolUpstreamTransport)
  })
_sym_db.RegisterMessage(ProxyProtocolUpstreamTransport)


DESCRIPTOR._options = None
_PROXYPROTOCOLUPSTREAMTRANSPORT.fields_by_name['transport_socket']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/service/cluster/v3/cds.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.service.discovery.v3 import discovery_pb2 as envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from envoy.annotations import resource_pb2 as envoy_dot_annotations_dot_resource__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/service/cluster/v3/cds.proto',
  package='envoy.service.cluster.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.service.cluster.v3B\010CdsProtoP\001\210\001\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"envoy/service/cluster/v3/cds.proto\x12\x18\x65nvoy.service.cluster.v3\x1a*envoy/service/discovery/v3/discovery.proto\x1a\x1cgoogle/api/annotations.proto\x1a envoy/annotations/resource.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"(\n\x08\x43\x64sDummy:\x1c\x9a\xc5\x88\x1e\x17\n\x15\x65nvoy.api.v2.CdsDummy2\xcd\x03\n\x17\x43lusterDiscoveryService\x12s\n\x0eStreamClusters\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\x00(\x01\x30\x01\x12|\n\rDeltaClusters\x12\x31.envoy.service.discovery.v3.DeltaDiscoveryRequest\x1a\x32.envoy.service.discovery.v3.DeltaDiscoveryResponse\"\x00(\x01\x30\x01\x12\x95\x01\n\rFetchClusters\x12,.envoy.service.discovery.v3.DiscoveryRequest\x1a-.envoy.service.discovery.v3.DiscoveryResponse\"\'\x82\xd3\xe4\x93\x02\x18\"\x16/v3/discovery:clusters\x82\xd3\xe4\x93\x02\x03:\x01*\x1a\'\x8a\xa4\x96\xf3\x07!\n\x1f\x65nvoy.config.cluster.v3.ClusterB?\n&io.envoyproxy.envoy.service.cluster.v3B\x08\x43\x64sProtoP\x01\x88\x01\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,envoy_dot_annotations_dot_resource__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_CDSDUMMY = _descriptor.Descriptor(
  name='CdsDummy',
  full_name='envoy.service.cluster.v3.CdsDummy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036\027\n\025envoy.api.v2.CdsDummy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=238,
  serialized_end=278,
)

DESCRIPTOR.message_types_by_name['CdsDummy'] = _CDSDUMMY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CdsDummy = _reflection.GeneratedProtocolMessageType('CdsDummy', (_message.Message,), {
  'DESCRIPTOR' : _CDSDUMMY,
  '__module__' : 'envoy.service.cluster.v3.cds_pb2'
  # @@protoc_insertion_point(class_scope:envoy.service.cluster.v3.CdsDummy)
  })
_sym_db.RegisterMessage(CdsDummy)


DESCRIPTOR._options = None
_CDSDUMMY._options = None

_CLUSTERDISCOVERYSERVICE = _descriptor.ServiceDescriptor(
  name='ClusterDiscoveryService',
  full_name='envoy.service.cluster.v3.ClusterDiscoveryService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\212\244\226\363\007!\n\037envoy.config.cluster.v3.Cluster',
  create_key=_descriptor._internal_create_key,
  serialized_start=281,
  serialized_end=742,
  methods=[
  _descriptor.MethodDescriptor(
    name='StreamClusters',
    full_name='envoy.service.cluster.v3.ClusterDiscoveryService.StreamClusters',
    index=0,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeltaClusters',
    full_name='envoy.service.cluster.v3.ClusterDiscoveryService.DeltaClusters',
    index=1,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DELTADISCOVERYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='FetchClusters',
    full_name='envoy.service.cluster.v3.ClusterDiscoveryService.FetchClusters',
    index=2,
    containing_service=None,
    input_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYREQUEST,
    output_type=envoy_dot_service_dot_discovery_dot_v3_dot_discovery__pb2._DISCOVERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\026/v3/discovery:clusters\202\323\344\223\002\003:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CLUSTERDISCOVERYSERVICE)

DESCRIPTOR.services_by_name['ClusterDiscoveryService'] = _CLUSTERDISCOVERYSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/kill_request/v3/kill_request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/kill_request/v3/kill_request.proto',
  package='envoy.extensions.filters.http.kill_request.v3',
  syntax='proto3',
  serialized_options=b'\n;io.envoyproxy.envoy.extensions.filters.http.kill_request.v3B\020KillRequestProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n@envoy/extensions/filters/http/kill_request/v3/kill_request.proto\x12-envoy.extensions.filters.http.kill_request.v3\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"n\n\x0bKillRequest\x12\x35\n\x0bprobability\x18\x01 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent\x12(\n\x13kill_request_header\x18\x02 \x01(\tB\x0b\xfa\x42\x08r\x06\xc0\x01\x02\xc8\x01\x00\x42Y\n;io.envoyproxy.envoy.extensions.filters.http.kill_request.v3B\x10KillRequestProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_KILLREQUEST = _descriptor.Descriptor(
  name='KillRequest',
  full_name='envoy.extensions.filters.http.kill_request.v3.KillRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='probability', full_name='envoy.extensions.filters.http.kill_request.v3.KillRequest.probability', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='kill_request_header', full_name='envoy.extensions.filters.http.kill_request.v3.KillRequest.kill_request_header', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\300\001\002\310\001\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=235,
  serialized_end=345,
)

_KILLREQUEST.fields_by_name['probability'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
DESCRIPTOR.message_types_by_name['KillRequest'] = _KILLREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KillRequest = _reflection.GeneratedProtocolMessageType('KillRequest', (_message.Message,), {
  'DESCRIPTOR' : _KILLREQUEST,
  '__module__' : 'envoy.extensions.filters.http.kill_request.v3.kill_request_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.kill_request.v3.KillRequest)
  })
_sym_db.RegisterMessage(KillRequest)


DESCRIPTOR._options = None
_KILLREQUEST.fields_by_name['kill_request_header']._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/endpoint/v3/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.endpoint.v3 import endpoint_components_pb2 as envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2
from envoy.type.v3 import percent_pb2 as envoy_dot_type_dot_v3_dot_percent__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/endpoint/v3/endpoint.proto',
  package='envoy.config.endpoint.v3',
  syntax='proto3',
  serialized_options=b'\n&io.envoyproxy.envoy.config.endpoint.v3B\rEndpointProtoP\001\272\200\310\321\006\002\020\002',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\'envoy/config/endpoint/v3/endpoint.proto\x12\x18\x65nvoy.config.endpoint.v3\x1a\x32\x65nvoy/config/endpoint/v3/endpoint_components.proto\x1a\x1b\x65nvoy/type/v3/percent.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\x1a\x17validate/validate.proto\"\x95\x07\n\x15\x43lusterLoadAssignment\x12\x1d\n\x0c\x63luster_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12@\n\tendpoints\x18\x02 \x03(\x0b\x32-.envoy.config.endpoint.v3.LocalityLbEndpoints\x12\\\n\x0fnamed_endpoints\x18\x05 \x03(\x0b\x32\x43.envoy.config.endpoint.v3.ClusterLoadAssignment.NamedEndpointsEntry\x12\x46\n\x06policy\x18\x04 \x01(\x0b\x32\x36.envoy.config.endpoint.v3.ClusterLoadAssignment.Policy\x1a\xee\x03\n\x06Policy\x12[\n\x0e\x64rop_overloads\x18\x02 \x03(\x0b\x32\x43.envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.DropOverload\x12\x46\n\x17overprovisioning_factor\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueB\x07\xfa\x42\x04*\x02 \x00\x12\x41\n\x14\x65ndpoint_stale_after\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationB\x08\xfa\x42\x05\xaa\x01\x02*\x00\x1a\xa3\x01\n\x0c\x44ropOverload\x12\x19\n\x08\x63\x61tegory\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01\x12\x39\n\x0f\x64rop_percentage\x18\x02 \x01(\x0b\x32 .envoy.type.v3.FractionalPercent:=\x9a\xc5\x88\x1e\x38\n6envoy.api.v2.ClusterLoadAssignment.Policy.DropOverload:0\x9a\xc5\x88\x1e+\n)envoy.api.v2.ClusterLoadAssignment.PolicyJ\x04\x08\x01\x10\x02J\x04\x08\x05\x10\x06R\x18\x64isable_overprovisioning\x1aY\n\x13NamedEndpointsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".envoy.config.endpoint.v3.Endpoint:\x02\x38\x01:)\x9a\xc5\x88\x1e$\n\"envoy.api.v2.ClusterLoadAssignmentBA\n&io.envoyproxy.envoy.config.endpoint.v3B\rEndpointProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x02\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2.DESCRIPTOR,envoy_dot_type_dot_v3_dot_percent__pb2.DESCRIPTOR,google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD = _descriptor.Descriptor(
  name='DropOverload',
  full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.DropOverload',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='category', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.DropOverload.category', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='drop_percentage', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.DropOverload.drop_percentage', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.api.v2.ClusterLoadAssignment.Policy.DropOverload',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=1001,
)

_CLUSTERLOADASSIGNMENT_POLICY = _descriptor.Descriptor(
  name='Policy',
  full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.Policy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='drop_overloads', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.drop_overloads', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='overprovisioning_factor', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.overprovisioning_factor', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004*\002 \000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint_stale_after', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.endpoint_stale_after', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\252\001\002*\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036+\n)envoy.api.v2.ClusterLoadAssignment.Policy',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=1089,
)

_CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY = _descriptor.Descriptor(
  name='NamedEndpointsEntry',
  full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.NamedEndpointsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.NamedEndpointsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.NamedEndpointsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1091,
  serialized_end=1180,
)

_CLUSTERLOADASSIGNMENT = _descriptor.Descriptor(
  name='ClusterLoadAssignment',
  full_name='envoy.config.endpoint.v3.ClusterLoadAssignment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='cluster_name', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.cluster_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoints', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.endpoints', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='named_endpoints', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.named_endpoints', index=2,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='policy', full_name='envoy.config.endpoint.v3.ClusterLoadAssignment.policy', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CLUSTERLOADASSIGNMENT_POLICY, _CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036$\n\"envoy.api.v2.ClusterLoadAssignment',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=1223,
)

_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD.fields_by_name['drop_percentage'].message_type = envoy_dot_type_dot_v3_dot_percent__pb2._FRACTIONALPERCENT
_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD.containing_type = _CLUSTERLOADASSIGNMENT_POLICY
_CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['drop_overloads'].message_type = _CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD
_CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['overprovisioning_factor'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['endpoint_stale_after'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_CLUSTERLOADASSIGNMENT_POLICY.containing_type = _CLUSTERLOADASSIGNMENT
_CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY.fields_by_name['value'].message_type = envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2._ENDPOINT
_CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY.containing_type = _CLUSTERLOADASSIGNMENT
_CLUSTERLOADASSIGNMENT.fields_by_name['endpoints'].message_type = envoy_dot_config_dot_endpoint_dot_v3_dot_endpoint__components__pb2._LOCALITYLBENDPOINTS
_CLUSTERLOADASSIGNMENT.fields_by_name['named_endpoints'].message_type = _CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY
_CLUSTERLOADASSIGNMENT.fields_by_name['policy'].message_type = _CLUSTERLOADASSIGNMENT_POLICY
DESCRIPTOR.message_types_by_name['ClusterLoadAssignment'] = _CLUSTERLOADASSIGNMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ClusterLoadAssignment = _reflection.GeneratedProtocolMessageType('ClusterLoadAssignment', (_message.Message,), {

  'Policy' : _reflection.GeneratedProtocolMessageType('Policy', (_message.Message,), {

    'DropOverload' : _reflection.GeneratedProtocolMessageType('DropOverload', (_message.Message,), {
      'DESCRIPTOR' : _CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD,
      '__module__' : 'envoy.config.endpoint.v3.endpoint_pb2'
      # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.ClusterLoadAssignment.Policy.DropOverload)
      })
    ,
    'DESCRIPTOR' : _CLUSTERLOADASSIGNMENT_POLICY,
    '__module__' : 'envoy.config.endpoint.v3.endpoint_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.ClusterLoadAssignment.Policy)
    })
  ,

  'NamedEndpointsEntry' : _reflection.GeneratedProtocolMessageType('NamedEndpointsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY,
    '__module__' : 'envoy.config.endpoint.v3.endpoint_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.ClusterLoadAssignment.NamedEndpointsEntry)
    })
  ,
  'DESCRIPTOR' : _CLUSTERLOADASSIGNMENT,
  '__module__' : 'envoy.config.endpoint.v3.endpoint_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.endpoint.v3.ClusterLoadAssignment)
  })
_sym_db.RegisterMessage(ClusterLoadAssignment)
_sym_db.RegisterMessage(ClusterLoadAssignment.Policy)
_sym_db.RegisterMessage(ClusterLoadAssignment.Policy.DropOverload)
_sym_db.RegisterMessage(ClusterLoadAssignment.NamedEndpointsEntry)


DESCRIPTOR._options = None
_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD.fields_by_name['category']._options = None
_CLUSTERLOADASSIGNMENT_POLICY_DROPOVERLOAD._options = None
_CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['overprovisioning_factor']._options = None
_CLUSTERLOADASSIGNMENT_POLICY.fields_by_name['endpoint_stale_after']._options = None
_CLUSTERLOADASSIGNMENT_POLICY._options = None
_CLUSTERLOADASSIGNMENT_NAMEDENDPOINTSENTRY._options = None
_CLUSTERLOADASSIGNMENT.fields_by_name['cluster_name']._options = None
_CLUSTERLOADASSIGNMENT._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/extensions/filters/http/compressor/v4alpha/compressor.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.config.core.v4alpha import base_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2
from envoy.config.core.v4alpha import extension_pb2 as envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from udpa.annotations import versioning_pb2 as udpa_dot_annotations_dot_versioning__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/extensions/filters/http/compressor/v4alpha/compressor.proto',
  package='envoy.extensions.filters.http.compressor.v4alpha',
  syntax='proto3',
  serialized_options=b'\n>io.envoyproxy.envoy.extensions.filters.http.compressor.v4alphaB\017CompressorProtoP\001\272\200\310\321\006\002\020\003',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\nAenvoy/extensions/filters/http/compressor/v4alpha/compressor.proto\x12\x30\x65nvoy.extensions.filters.http.compressor.v4alpha\x1a$envoy/config/core/v4alpha/base.proto\x1a)envoy/config/core/v4alpha/extension.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1dudpa/annotations/status.proto\x1a!udpa/annotations/versioning.proto\"\x8c\n\n\nCompressor\x12K\n\x12\x63ompressor_library\x18\x06 \x01(\x0b\x32/.envoy.config.core.v4alpha.TypedExtensionConfig\x12u\n\x18request_direction_config\x18\x07 \x01(\x0b\x32S.envoy.extensions.filters.http.compressor.v4alpha.Compressor.RequestDirectionConfig\x12w\n\x19response_direction_config\x18\x08 \x01(\x0b\x32T.envoy.extensions.filters.http.compressor.v4alpha.Compressor.ResponseDirectionConfig\x1a\xfc\x01\n\x15\x43ommonDirectionConfig\x12>\n\x07\x65nabled\x18\x01 \x01(\x0b\x32-.envoy.config.core.v4alpha.RuntimeFeatureFlag\x12\x38\n\x12min_content_length\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32Value\x12\x14\n\x0c\x63ontent_type\x18\x03 \x03(\t:S\x9a\xc5\x88\x1eN\nLenvoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig\x1a\xd9\x01\n\x16RequestDirectionConfig\x12i\n\rcommon_config\x18\x01 \x01(\x0b\x32R.envoy.extensions.filters.http.compressor.v4alpha.Compressor.CommonDirectionConfig:T\x9a\xc5\x88\x1eO\nMenvoy.extensions.filters.http.compressor.v3.Compressor.RequestDirectionConfig\x1a\xa2\x02\n\x17ResponseDirectionConfig\x12i\n\rcommon_config\x18\x01 \x01(\x0b\x32R.envoy.extensions.filters.http.compressor.v4alpha.Compressor.CommonDirectionConfig\x12\x1e\n\x16\x64isable_on_etag_header\x18\x02 \x01(\x08\x12%\n\x1dremove_accept_encoding_header\x18\x03 \x01(\x08:U\x9a\xc5\x88\x1eP\nNenvoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig:=\x9a\xc5\x88\x1e\x38\n6envoy.extensions.filters.http.compressor.v3.CompressorJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06R\x0e\x63ontent_lengthR\x0c\x63ontent_typeR\x16\x64isable_on_etag_headerR\x1dremove_accept_encoding_headerR\x0fruntime_enabledB[\n>io.envoyproxy.envoy.extensions.filters.http.compressor.v4alphaB\x0f\x43ompressorProtoP\x01\xba\x80\xc8\xd1\x06\x02\x10\x03\x62\x06proto3'
  ,
  dependencies=[envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2.DESCRIPTOR,envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,udpa_dot_annotations_dot_versioning__pb2.DESCRIPTOR,])




_COMPRESSOR_COMMONDIRECTIONCONFIG = _descriptor.Descriptor(
  name='CommonDirectionConfig',
  full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.CommonDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='enabled', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.CommonDirectionConfig.enabled', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_content_length', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.CommonDirectionConfig.min_content_length', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_type', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.CommonDirectionConfig.content_type', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036N\nLenvoy.extensions.filters.http.compressor.v3.Compressor.CommonDirectionConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=631,
  serialized_end=883,
)

_COMPRESSOR_REQUESTDIRECTIONCONFIG = _descriptor.Descriptor(
  name='RequestDirectionConfig',
  full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.RequestDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.RequestDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036O\nMenvoy.extensions.filters.http.compressor.v3.Compressor.RequestDirectionConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=886,
  serialized_end=1103,
)

_COMPRESSOR_RESPONSEDIRECTIONCONFIG = _descriptor.Descriptor(
  name='ResponseDirectionConfig',
  full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.ResponseDirectionConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='common_config', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.ResponseDirectionConfig.common_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='disable_on_etag_header', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.ResponseDirectionConfig.disable_on_etag_header', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='remove_accept_encoding_header', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.ResponseDirectionConfig.remove_accept_encoding_header', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\036P\nNenvoy.extensions.filters.http.compressor.v3.Compressor.ResponseDirectionConfig',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1106,
  serialized_end=1396,
)

_COMPRESSOR = _descriptor.Descriptor(
  name='Compressor',
  full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='compressor_library', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.compressor_library', index=0,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_direction_config', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.request_direction_config', index=1,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_direction_config', full_name='envoy.extensions.filters.http.compressor.v4alpha.Compressor.response_direction_config', index=2,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_COMPRESSOR_COMMONDIRECTIONCONFIG, _COMPRESSOR_REQUESTDIRECTIONCONFIG, _COMPRESSOR_RESPONSEDIRECTIONCONFIG, ],
  enum_types=[
  ],
  serialized_options=b'\232\305\210\0368\n6envoy.extensions.filters.http.compressor.v3.Compressor',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=299,
  serialized_end=1591,
)

_COMPRESSOR_COMMONDIRECTIONCONFIG.fields_by_name['enabled'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_base__pb2._RUNTIMEFEATUREFLAG
_COMPRESSOR_COMMONDIRECTIONCONFIG.fields_by_name['min_content_length'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT32VALUE
_COMPRESSOR_COMMONDIRECTIONCONFIG.containing_type = _COMPRESSOR
_COMPRESSOR_REQUESTDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _COMPRESSOR_COMMONDIRECTIONCONFIG
_COMPRESSOR_REQUESTDIRECTIONCONFIG.containing_type = _COMPRESSOR
_COMPRESSOR_RESPONSEDIRECTIONCONFIG.fields_by_name['common_config'].message_type = _COMPRESSOR_COMMONDIRECTIONCONFIG
_COMPRESSOR_RESPONSEDIRECTIONCONFIG.containing_type = _COMPRESSOR
_COMPRESSOR.fields_by_name['compressor_library'].message_type = envoy_dot_config_dot_core_dot_v4alpha_dot_extension__pb2._TYPEDEXTENSIONCONFIG
_COMPRESSOR.fields_by_name['request_direction_config'].message_type = _COMPRESSOR_REQUESTDIRECTIONCONFIG
_COMPRESSOR.fields_by_name['response_direction_config'].message_type = _COMPRESSOR_RESPONSEDIRECTIONCONFIG
DESCRIPTOR.message_types_by_name['Compressor'] = _COMPRESSOR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Compressor = _reflection.GeneratedProtocolMessageType('Compressor', (_message.Message,), {

  'CommonDirectionConfig' : _reflection.GeneratedProtocolMessageType('CommonDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _COMPRESSOR_COMMONDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.compressor.v4alpha.compressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v4alpha.Compressor.CommonDirectionConfig)
    })
  ,

  'RequestDirectionConfig' : _reflection.GeneratedProtocolMessageType('RequestDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _COMPRESSOR_REQUESTDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.compressor.v4alpha.compressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v4alpha.Compressor.RequestDirectionConfig)
    })
  ,

  'ResponseDirectionConfig' : _reflection.GeneratedProtocolMessageType('ResponseDirectionConfig', (_message.Message,), {
    'DESCRIPTOR' : _COMPRESSOR_RESPONSEDIRECTIONCONFIG,
    '__module__' : 'envoy.extensions.filters.http.compressor.v4alpha.compressor_pb2'
    # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v4alpha.Compressor.ResponseDirectionConfig)
    })
  ,
  'DESCRIPTOR' : _COMPRESSOR,
  '__module__' : 'envoy.extensions.filters.http.compressor.v4alpha.compressor_pb2'
  # @@protoc_insertion_point(class_scope:envoy.extensions.filters.http.compressor.v4alpha.Compressor)
  })
_sym_db.RegisterMessage(Compressor)
_sym_db.RegisterMessage(Compressor.CommonDirectionConfig)
_sym_db.RegisterMessage(Compressor.RequestDirectionConfig)
_sym_db.RegisterMessage(Compressor.ResponseDirectionConfig)


DESCRIPTOR._options = None
_COMPRESSOR_COMMONDIRECTIONCONFIG._options = None
_COMPRESSOR_REQUESTDIRECTIONCONFIG._options = None
_COMPRESSOR_RESPONSEDIRECTIONCONFIG._options = None
_COMPRESSOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from envoy.api.v2.core import address_pb2 as envoy_dot_api_dot_v2_dot_core_dot_address__pb2
from udpa.annotations import migrate_pb2 as udpa_dot_annotations_dot_migrate__pb2
from udpa.annotations import status_pb2 as udpa_dot_annotations_dot_status__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto',
  package='envoy.config.filter.http.ip_tagging.v2',
  syntax='proto3',
  serialized_options=b'\n4io.envoyproxy.envoy.config.filter.http.ip_tagging.v2B\016IpTaggingProtoP\001\362\230\376\217\005-\022+envoy.extensions.filters.http.ip_tagging.v3\272\200\310\321\006\002\020\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n7envoy/config/filter/http/ip_tagging/v2/ip_tagging.proto\x12&envoy.config.filter.http.ip_tagging.v2\x1a\x1f\x65nvoy/api/v2/core/address.proto\x1a\x1eudpa/annotations/migrate.proto\x1a\x1dudpa/annotations/status.proto\x1a\x17validate/validate.proto\"\xc0\x02\n\tIPTagging\x12]\n\x0crequest_type\x18\x01 \x01(\x0e\x32=.envoy.config.filter.http.ip_tagging.v2.IPTagging.RequestTypeB\x08\xfa\x42\x05\x82\x01\x02\x10\x01\x12R\n\x07ip_tags\x18\x04 \x03(\x0b\x32\x37.envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTagB\x08\xfa\x42\x05\x92\x01\x02\x08\x01\x1aK\n\x05IPTag\x12\x13\n\x0bip_tag_name\x18\x01 \x01(\t\x12-\n\x07ip_list\x18\x02 \x03(\x0b\x32\x1c.envoy.api.v2.core.CidrRange\"3\n\x0bRequestType\x12\x08\n\x04\x42OTH\x10\x00\x12\x0c\n\x08INTERNAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\x42\x83\x01\n4io.envoyproxy.envoy.config.filter.http.ip_tagging.v2B\x0eIpTaggingProtoP\x01\xf2\x98\xfe\x8f\x05-\x12+envoy.extensions.filters.http.ip_tagging.v3\xba\x80\xc8\xd1\x06\x02\x10\x01\x62\x06proto3'
  ,
  dependencies=[envoy_dot_api_dot_v2_dot_core_dot_address__pb2.DESCRIPTOR,udpa_dot_annotations_dot_migrate__pb2.DESCRIPTOR,udpa_dot_annotations_dot_status__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_IPTAGGING_REQUESTTYPE = _descriptor.EnumDescriptor(
  name='RequestType',
  full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.RequestType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BOTH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXTERNAL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=490,
  serialized_end=541,
)
_sym_db.RegisterEnumDescriptor(_IPTAGGING_REQUESTTYPE)


_IPTAGGING_IPTAG = _descriptor.Descriptor(
  name='IPTag',
  full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ip_tag_name', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag.ip_tag_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_list', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag.ip_list', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=413,
  serialized_end=488,
)

_IPTAGGING = _descriptor.Descriptor(
  name='IPTagging',
  full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_type', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.request_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\202\001\002\020\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ip_tags', full_name='envoy.config.filter.http.ip_tagging.v2.IPTagging.ip_tags', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\222\001\002\010\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_IPTAGGING_IPTAG, ],
  enum_types=[
    _IPTAGGING_REQUESTTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=541,
)

_IPTAGGING_IPTAG.fields_by_name['ip_list'].message_type = envoy_dot_api_dot_v2_dot_core_dot_address__pb2._CIDRRANGE
_IPTAGGING_IPTAG.containing_type = _IPTAGGING
_IPTAGGING.fields_by_name['request_type'].enum_type = _IPTAGGING_REQUESTTYPE
_IPTAGGING.fields_by_name['ip_tags'].message_type = _IPTAGGING_IPTAG
_IPTAGGING_REQUESTTYPE.containing_type = _IPTAGGING
DESCRIPTOR.message_types_by_name['IPTagging'] = _IPTAGGING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IPTagging = _reflection.GeneratedProtocolMessageType('IPTagging', (_message.Message,), {

  'IPTag' : _reflection.GeneratedProtocolMessageType('IPTag', (_message.Message,), {
    'DESCRIPTOR' : _IPTAGGING_IPTAG,
    '__module__' : 'envoy.config.filter.http.ip_tagging.v2.ip_tagging_pb2'
    # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ip_tagging.v2.IPTagging.IPTag)
    })
  ,
  'DESCRIPTOR' : _IPTAGGING,
  '__module__' : 'envoy.config.filter.http.ip_tagging.v2.ip_tagging_pb2'
  # @@protoc_insertion_point(class_scope:envoy.config.filter.http.ip_tagging.v2.IPTagging)
  })
_sym_db.RegisterMessage(IPTagging)
_sym_db.RegisterMessage(IPTagging.IPTag)


DESCRIPTOR._options = None
_IPTAGGING.fields_by_name['request_type']._options = None
_IPTAGGING.fields_by_name['ip_tags']._options = None
# @@protoc_insertion_point(module_scope)
